@@ -107,27 +107,37 @@ func NewPermalinkExpander(urlize func(uri string) string, patterns map[string]ma
 	return p, nil
 }
 
+// Escape sequence for colons in permalink patterns.
+const escapePlaceholderColon = "\x00"
+
+func (l PermalinkExpander) normalizeEscapeSequencesIn(s string) (string, bool) {
+	s2 := strings.ReplaceAll(s, "\\:", escapePlaceholderColon)
+	return s2, s2 != s
+}
+
+func (l PermalinkExpander) normalizeEscapeSequencesOut(result string) string {
+	return strings.ReplaceAll(result, escapePlaceholderColon, ":")
+}
+
 // ExpandPattern expands the path in p with the specified expand pattern.
 func (l PermalinkExpander) ExpandPattern(pattern string, p Page) (string, error) {
-	expander, err := l.getOrParsePattern(pattern)
+	expand, err := l.getOrParsePattern(pattern)
 	if err != nil {
 		return "", err
 	}
 
-	return expander(p)
+	return expand(p)
 }
 
 // Expand expands the path in p according to the rules defined for the given key.
 // If no rules are found for the given key, an empty string is returned.
 func (l PermalinkExpander) Expand(key string, p Page) (string, error) {
 	expanders, found := l.expanders[p.Kind()]
-
 	if !found {
 		return "", nil
 	}
 
 	expand, found := expanders[key]
-
 	if !found {
 		return "", nil
 	}
@@ -149,7 +159,19 @@ func (l PermalinkExpander) getOrParsePattern(pattern string) (func(Page) (string
 		if !l.validate(pattern) {
 			return nil, &permalinkExpandError{pattern: pattern, err: errPermalinkIllFormed}
 		}
+		var normalized bool
+		pattern, normalized = l.normalizeEscapeSequencesIn(pattern)
+
 		matches := attributeRegexp.FindAllStringSubmatch(pattern, -1)
+		if matches == nil {
+			result := pattern
+			if normalized {
+				result = l.normalizeEscapeSequencesOut(result)
+			}
+			return func(p Page) (string, error) {
+				return result, nil
+			}, nil
+		}
 
 		callbacks := make([]pageToPermaAttribute, len(matches))
 		replacements := make([]string, len(matches))
@@ -167,10 +189,6 @@ func (l PermalinkExpander) getOrParsePattern(pattern string) (func(Page) (string
 		}
 
 		return func(p Page) (string, error) {
-			if matches == nil {
-				return pattern, nil
-			}
-
 			newField := pattern
 
 			for i, replacement := range replacements {
@@ -184,6 +202,10 @@ func (l PermalinkExpander) getOrParsePattern(pattern string) (func(Page) (string
 				newField = strings.Replace(newField, replacement, newAttr, 1)
 			}
 
+			if normalized {
+				newField = l.normalizeEscapeSequencesOut(newField)
+			}
+
 			return newField, nil
 		}, nil
 	})
